# Impact UKA

This is a Python reimplementation of the Java uka package utilized in the original
Imapct Java application - https://sourceforge.net/projects/impact/

A 2025 update of the original Java application is available at:

* https://gitlab.com/impact-analysis/impact-java-2025


# The Original Implementaion was (Partially) Licenced As Follows

```
/* ********************************************************************
 * KaRMI
 *
 * Copyright (C) 1998-2003 The JavaParty Team, University of Karlsruhe
 *
 * Permission is hereby granted to use and modify this software.
 * The software, or modifications thereof, may be redistributed only
 * if the source code is also provided and this copyright notice stays 
 * attached.
 **********************************************************************/
 ```

# KaRMI Links

## Original Java Implementation

This appears to have been the original GIT repo for the Java implementation,
however, it is now no longer available.  Searches on KaRMI and JavaParty in
GitHub yield no public results.

* https://github.com/JavaParty/KaRMI

This URL exists - https://github.com/javaparty - but is devoid of public content.

## Original Java Implementation Papers

An Internet search on JavaParty and KaRMI yielded some results, including the
following papers:

* https://www.researchgate.net/publication/220949796_Transparent_Distributed_Threads_for_Java
* https://zenger.org/papers/party.pdf
* https://cris.fau.de/projects/290001506/?lang=de_DE
* https://publikationen.bibliothek.kit.edu/30482001
* https://www.semanticscholar.org/paper/Exploiting-object-locality-in-JavaParty%2C-a-for-Haumacher-Philippsen/f4c86aa30e408fecc58d8b1bf120da279abe7028#related-papers
* https://www.semanticscholar.org/paper/JavaParty-%E2%80%93-transparent-remote-objects-in-Java-Philippsen-Zenger/f0f616e25fd345b110cc8e4d02c2f3a7bb50a103


# Other Links

* https://scientiaeducare.com/karlsruhe-institute-of-technology-germany/


